# Parsing access statistics from Docker logs

Until the COUNTER statistics are implemented in InvenioRDM, these scripts can help with getting some rough estimates from parsing the services' logs.

*Please note* that the statistics here are very naïvely calculated and should thus be taken with a grain of salt.


## `opensearch.sh`

This script can be used to collect the logs from our services from our central OpenSearch log server and print them out to `stdout`.  
It assumes that one service's logs can be filtered by querying for a specific `@log_name` (e.g. as set by `fluentd`).

Its behavior can be changed with the following environment variables:
* `OPENSEARCH_USERNAME`: The username for authentication in OpenSearch (required)
* `OPENSEARCH_PASSWORD`: The password for authentication in OpenSearch (required)
* `OPENSEARCH_URL`: The URL under which OpenSearch is reachable (default: `https://s63.dl.hpc.tuwien.ac.at:9200`)
* `OPENSEARCH_INDEX_PATTERN`:  (default: `logstash-tudata-main-*`)
* `OPENSEARCH_LOG_NAME` The value of `@log_name` to filter for (default: `nginx.main`)

### Prerequisites

* `curl`
* `jq`
* `sed`

### Example

```bash
# zsh won't add an input to the history if it starts with whitespace
 export OPENSEARCH_USERNAME=frank OPENSEARCH_PASSWORD=password1234

./opensearch.sh > nginx.log
OPENSEARCH_LOG_NAME=ui.main ./opensearch.sh > uwsgi-ui.log
```


## `from-docker-logs.py`

The original script for parsing the Web-UI's `uwsgi` logs and naïvely calculating download statistics, written in Python.


### Prerequisites

* `python` v3.8
* `pendulum`: Python package for parsing timestamps

### Example

```bash
python from-docker-logs.py -r < uwsgi-ui.log

# more help is available with the `--help` flag
python from-docker-logs.py --help
```


## `go/statistics`

A `golang`-based reimplementation of `from-docker-logs.py`, which parses logs from `nginx` rather than `uwsgi`.
It aims to provide better performance than `from-docker-logs.py`.
Also, it's always interesting to try out a new language!

This program somewhat assumes the `nginx` [default log format](https://en.wikipedia.org/wiki/Common_Log_Format), especially for datetimes.
They should follow the format `"%d/%b/%Y:%H:%M:%S %z"`, e.g. `02/Jan/2006:15:04:05 -0700`.

### Prerequisites

* `go` v1.19

### Example

```bash
# run the code directly
go run . < nginx.log

# or build the binary first and then execute it
go build
./statistics < nginx.log
```
