#!/bin/bash
#
# collect all the logs for a given service from OpenSearch
# exported environment variables controlling the behaviour:
#
# OPENSEARCH_USERNAME
# OPENSEARCH_PASSWORD
# OPENSEARCH_URL
# OPENSEARCH_INDEX_PATTERN
# OPENSEARCH_LOG_NAME

set -uo pipefail

continue=1
values=''
latest_sort=0
orig_query='{
    "query": {
        "match": {
            "@log_name": "LOG_NAME"
        }
    },
    "size": 10000,
    "sort": [
        {"@timestamp": "asc"}
    ],
    "search_after": [LATEST_SORT]
}'
username="${OPENSEARCH_USERNAME}"
password="${OPENSEARCH_PASSWORD}"
host="${OPENSEARCH_URL:-https://s63.dl.hpc.tuwien.ac.at:9200}"
index_pattern="${OPENSEARCH_INDEX_PATTERN:-logstash-tudata-main-*}"
log_name="${OPENSEARCH_LOG_NAME:-nginx.main}"

# test the waters, to see if the requests work (especially regarding authentication)
curl -s -f -u "${username}:${password}" "${host}/_cat" > /dev/null

# as long as there's still hits, keep querying...
while [[ "${continue}" -gt 0 ]]; do
    # update the query to incorporate the latest 'sort' value (will be 0 the first time around)
    query=$(echo "${orig_query}" | sed -e "s/LATEST_SORT/${latest_sort}/" -e "s/LOG_NAME/${log_name}/")

    # fetch the values, and print them
    values=$(curl -s -X GET -H "content-type: application/json" -u "${username}:${password}" "${host}/${index_pattern}/_search" -d "${query}")
    echo "${values}" | jq -r '.hits.hits[]._source.log' 2>/dev/null

    # fetch the latest 'sort' value
    latest_sort="$(echo "${values}" | jq '.hits.hits[-1].sort[]' 2>/dev/null)"

    # check if the loop should continue
    num_results="$(echo "${values}" | jq '.hits.total.value')"
    if [[ "${num_results}" != "null" && "${num_results}" -gt 0 ]]; then
        continue=1
    else
        continue=0
    fi
done
